OpenEA
======

.. currentmodule:: pykeen.datasets

.. autoclass:: OpenEA
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~OpenEA.FIGSHARE_LINK
      ~OpenEA.SHA512

   .. rubric:: Attributes Documentation

   .. autoattribute:: FIGSHARE_LINK
   .. autoattribute:: SHA512
